StateVariable class

A variable that represents a value in the service's state.

Constructors

StateVariable({bool? sendEvents, bool? multicast, required String name, required DataType dataType, String? defaultValue, List<String>? allowedValues, AllowedValueRange? allowedValueRange})
StateVariable.fromXml(XmlNode xml)
factory

Properties

allowedValueRange AllowedValueRange?
Defines bounds and resolution for numeric values.
final
allowedValues List<String>?
Enumerates legal string values.
final
dataType DataType
DataType of this variable.
final
defaultValue String?
Expected, initial value.
final
hashCode int
The hash code for this object.
no setterinherited
multicast bool?
Defines if event messages will be delivered using multicast eventing.
final
name String
Name of the state variable.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendEvents bool?
If event messages are generated when the value of this variable changes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited